from setuptools import setup

setup(
    name='pfrl',
    version='0.0.0',
    description='',
    long_description='',
    author='Yasuhiro Fujita',
    author_email='muupan@gmail.com',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
